/**
 * Predefined hook to store and retrieve the previous value of the given reference to a string.
 *
 * @param value Reference to a string that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
export declare const usePreviousString: (value: string, initialPreviousValue?: string) => string;
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a string array.
 *
 * @param value Reference to a string array that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
export declare const usePreviousStringArray: (value: string[], initialPreviousValue?: string[]) => string[];
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a number.
 *
 * @param value Reference to a number that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
export declare const usePreviousNumber: (value: number, initialPreviousValue?: number) => number;
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a number array.
 *
 * @param value Reference to a number array that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
export declare const usePreviousNumberArray: (value: number[], initialPreviousValue?: number[]) => number[];
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a boolean.
 *
 * @param value Reference to a boolean that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
export declare const usePreviousBoolean: (value: boolean, initialPreviousValue?: boolean) => boolean;
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a boolean array.
 *
 * @param value Reference to a boolean array that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
export declare const usePreviousBooleanArray: (value: boolean[], initialPreviousValue?: boolean[]) => boolean[];
/**
 * Generic hook to store and retrieve the previous value of the given reference.
 *
 * @param value Reference to a value / property that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
declare const usePrevious: <T>(value: T, initialPreviousValue: T) => T;
export default usePrevious;
