"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a string.
 *
 * @param value Reference to a string that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
exports.usePreviousString = (value, initialPreviousValue = '') => usePrevious(value, initialPreviousValue);
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a string array.
 *
 * @param value Reference to a string array that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
exports.usePreviousStringArray = (value, initialPreviousValue = []) => usePrevious(value, initialPreviousValue);
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a number.
 *
 * @param value Reference to a number that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
exports.usePreviousNumber = (value, initialPreviousValue = 0) => usePrevious(value, initialPreviousValue);
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a number array.
 *
 * @param value Reference to a number array that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
exports.usePreviousNumberArray = (value, initialPreviousValue = []) => usePrevious(value, initialPreviousValue);
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a boolean.
 *
 * @param value Reference to a boolean that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
exports.usePreviousBoolean = (value, initialPreviousValue = false) => usePrevious(value, initialPreviousValue);
/**
 * Predefined hook to store and retrieve the previous value of the given reference to a boolean array.
 *
 * @param value Reference to a boolean array that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
exports.usePreviousBooleanArray = (value, initialPreviousValue = []) => usePrevious(value, initialPreviousValue);
/**
 * Generic hook to store and retrieve the previous value of the given reference.
 *
 * @param value Reference to a value / property that will be watched so that the previous value will always be updated
 * with the old value when the current value changes.
 * @param initialPreviousValue The initial value this hook should return as the default previous value as long as
 * the watched property was not updated.
 */
const usePrevious = (value, initialPreviousValue) => {
    const ref = react_1.useRef(initialPreviousValue);
    react_1.useEffect(() => {
        ref.current = value;
    }, [value]);
    return ref.current;
};
exports.default = usePrevious;
//# sourceMappingURL=usePrevious.js.map