"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_hooks_1 = require("@testing-library/react-hooks");
const usePrevious_1 = require("./usePrevious");
const react_1 = require("react");
describe('test react-hooks-use-previous', () => {
    it('should call usePrevious successfully', () => {
        const value = 0;
        const { result } = react_hooks_1.renderHook(() => usePrevious_1.default(value, 0));
        expect(result.current).toBe(0);
    });
    it('should call usePreviousString successfully and assign the correct default value', () => {
        const value = '';
        const { result } = react_hooks_1.renderHook(() => usePrevious_1.usePreviousString(value));
        expect(result.current).toBe('');
    });
    it('should call usePreviousStringArray successfully and assign the correct default value', () => {
        const value = [''];
        const { result } = react_hooks_1.renderHook(() => usePrevious_1.usePreviousStringArray(value));
        expect(result.current).toEqual([]);
    });
    it('should call usePreviousNumber successfully and assign the correct default value', () => {
        const value = 0;
        const { result } = react_hooks_1.renderHook(() => usePrevious_1.usePreviousNumber(value));
        expect(result.current).toBe(0);
    });
    it('should call usePreviousNumberArray successfully and assign the correct default value', () => {
        const value = [0];
        const { result } = react_hooks_1.renderHook(() => usePrevious_1.usePreviousNumberArray(value));
        expect(result.current).toEqual([]);
    });
    it('should call usePreviousBoolean successfully and assign the correct default value', () => {
        const value = false;
        const { result } = react_hooks_1.renderHook(() => usePrevious_1.usePreviousBoolean(value));
        expect(result.current).toBe(false);
    });
    it('should call usePreviousBooleanArray successfully and assign the correct default value', () => {
        const value = [false];
        const { result } = react_hooks_1.renderHook(() => usePrevious_1.usePreviousBooleanArray(value));
        expect(result.current).toEqual([]);
    });
    it('should return the previous value when updating the associated state variable', () => {
        const useTestHook = () => {
            const [value, setValue] = react_1.useState(77);
            const prevValue = usePrevious_1.default(value, 0);
            return { value, setValue, prevValue };
        };
        const { result } = react_hooks_1.renderHook(() => useTestHook());
        expect(result.current.prevValue).toBe(0);
        expect(result.current.value).toBe(77);
        react_hooks_1.act(() => {
            result.current.setValue(33);
        });
        expect(result.current.prevValue).toBe(77);
        expect(result.current.value).toBe(33);
    });
});
//# sourceMappingURL=usePrevious.test.js.map